import { useQuery } from '@apollo/client'
import React from 'react'
import { useTranslation } from 'react-i18next'

import { HeaderButtonProps } from '@react-navigation/native-stack/lib/typescript/src/types'

import { useToastForNotAvailableFeature } from '@holi/core/helpers'
import NotificationBadge from '@holi/core/navigation/components/NotificationBadge'
import useRouting from '@holi/core/navigation/hooks/useRouting'
import { HasNewNotificationsQuery, HasNewNotificationsResponse } from '@holi/core/screens/notifications/queries'
import { useLoggedInUser } from '@holi/core/screens/userprofile/useLoggedInUser'
import { HoliIcon } from '@holi/icons/src/HoliIcon'
import { Notification2, Search } from '@holi/icons/src/generated'
import HoliButton from '@holi/ui/components/molecules/HoliButton'
import { HoliHorizontalRow } from '@holi/ui/components/molecules/HoliHorizontalRow'

const NOTIFICATION_POLLING_INTERVAL = process.env.NOTIFICATION_POLLING_INTERVAL
  ? parseInt(process.env.NOTIFICATION_POLLING_INTERVAL, 10)
  : 5000

const NotificationSearchButtons = ({ tintColor }: HeaderButtonProps) => {
  const { t } = useTranslation()
  const { navigate } = useRouting()
  const { isLoggedIn } = useLoggedInUser()

  const { data } = useQuery<HasNewNotificationsResponse>(HasNewNotificationsQuery, {
    skip: !isLoggedIn,
    fetchPolicy: 'network-only',
    pollInterval: NOTIFICATION_POLLING_INTERVAL,
  })

  const hasNewNotifications = !!data?.hasNewNotifications?.status

  // TODO: remove after implementing the feature
  const showFeatureNotImplementedToast = useToastForNotAvailableFeature()

  return (
    <HoliHorizontalRow>
      <NotificationBadge visible={hasNewNotifications}>
        <HoliButton
          label={t('notifications.title')}
          inline
          testID="btn-to-notifications"
          transparent
          onPress={() => {
            navigate('/notifications')
          }}
        >
          <HoliIcon icon={Notification2} color={tintColor} />
        </HoliButton>
      </NotificationBadge>

      <HoliButton
        label={t('navigation.search')}
        inline
        transparent
        onPress={() => {
          // TODO: remove after implementing the feature
          showFeatureNotImplementedToast()
          // navigate('/search')
        }}
      >
        <HoliIcon icon={Search} color={tintColor} />
      </HoliButton>
    </HoliHorizontalRow>
  )
}

export default NotificationSearchButtons
